# -*- coding: utf-8 -*-

"""
scikit-ci enables a centralized and simpler CI configuration for Python
extensions.
"""

from .constants import STEPS
from .driver import execute_step

__author__ = 'The scikit-build team'
__email__ = 'scikit-build@googlegroups.com'
__version__ = '0.5.0'

__all__ = ["execute_step", "STEPS"]



# -*- coding: utf-8 -*-

"""This module defines functions generally useful in scikit-ci."""

import os

from .constants import SERVICES, SERVICES_ENV_VAR


def current_service():
    for service, env_var in SERVICES_ENV_VAR.items():
        if os.environ.get(env_var, 'false').lower() == 'true':
            return service
    raise LookupError(
        "unknown service: None of the environment variables {} are set "
        "to 'true' or 'True'".format(", ".join(SERVICES_ENV_VAR.values()))
    )


def current_operating_system(service):
    return os.environ[SERVICES[service]] if SERVICES[service] else None



# -*- coding: utf-8 -*-

"""
Ci command line tool (enable python -m ci syntax)
"""

import ci
import os


def main():
    """The main entry point to ``ci.py``.

    This is installed as the script entry point.
    """

    import argparse

    version_str = ("This is scikit-ci version %s, imported from %s\n" %
                   (ci.__version__, os.path.abspath(ci.__file__)))

    parser = argparse.ArgumentParser(description=ci.__doc__)
    parser.add_argument(
        "step", type=str, choices=ci.STEPS,
        help="name of the step to execute")
    parser.add_argument(
        "--version", action="version",
        version=version_str,
        help="display scikit-ci version and import information.")
    args = parser.parse_args()

    ci.execute_step(args.step)


if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-

SCIKIT_CI_CONFIG = "scikit-ci.yml"
"""Name of the configuration."""

SERVICES = {
    "appveyor": None,
    "circle": None,
    "travis": "TRAVIS_OS_NAME"
}
"""Describes the supported services.

Service associated with only one "implicit" operating system
are associated with the value ``None``.

Service supporting multiple operating systems (e.g. travis) are
associated with the name of environment variable describing the
operating system in use. (e.g ``TRAVIS_OS_NAME``).
"""

SERVICES_ENV_VAR = {
    "appveyor": "APPVEYOR",
    "circle": "CIRCLECI",
    "travis": "TRAVIS",
}

STEPS = [
    "before_install",
    "install",
    "before_build",
    "build",
    "test",
    "after_test"
]
"""Name of the CI steps.

These are the scikit-ci steps to execute. They are expected to
be mapped to the step recognized by continuous integration
services like Appveyor, CircleCI or TravisCI.
"""
